@@ -9,19 +9,33 @@ from ..readers import InputExample
 
 logger = logging.getLogger(__name__)
 
+
 class TripletEvaluator(SentenceEvaluator):
     """
-    Evaluate a model based on a triplet: (sentence, positive_example, negative_example). Checks if distance(sentence,positive_example) < distance(sentence, negative_example).
+    Evaluate a model based on a triplet: (sentence, positive_example, negative_example).
+        Checks if distance(sentence, positive_example) < distance(sentence, negative_example).
     """
-    def __init__(self, anchors: List[str], positives: List[str], negatives: List[str], main_distance_function: SimilarityFunction = None, name: str = '', batch_size: int = 16, show_progress_bar: bool = False):
+
+    def __init__(
+        self,
+        anchors: List[str],
+        positives: List[str],
+        negatives: List[str],
+        main_distance_function: SimilarityFunction = None,
+        name: str = "",
+        batch_size: int = 16,
+        show_progress_bar: bool = False,
+        write_csv: bool = True,
+    ):
         """
-        Constructs an evaluator based for the dataset
-
-
-        :param dataloader:
-            the data for the evaluation
-        :param main_similarity:
-            the similarity metric that will be used for the returned score
+        :param anchors: Sentences to check similarity to. (e.g. a query)
+        :param positives: List of positive sentences
+        :param negatives: List of negative sentences
+        :param main_distance_function: One of 0 (Cosine), 1 (Euclidean) or 2 (Manhattan). Defaults to None, returning all 3.
+        :param name: Name for the output
+        :param batch_size: Batch size used to compute embeddings
+        :param show_progress_bar: If true, prints a progress bar
+        :param write_csv: Write results to a CSV file
         """
         self.anchors = anchors
         self.positives = positives
@@ -35,11 +49,14 @@ class TripletEvaluator(SentenceEvaluator):
 
         self.batch_size = batch_size
         if show_progress_bar is None:
-            show_progress_bar = (logger.getEffectiveLevel() == logging.INFO or logger.getEffectiveLevel() == logging.DEBUG)
+            show_progress_bar = (
+                logger.getEffectiveLevel() == logging.INFO or logger.getEffectiveLevel() == logging.DEBUG
+            )
         self.show_progress_bar = show_progress_bar
 
-        self.csv_file: str = "triplet_evaluation"+("_"+name if name else '')+"_results.csv"
+        self.csv_file: str = "triplet_evaluation" + ("_" + name if name else "") + "_results.csv"
         self.csv_headers = ["epoch", "steps", "accuracy_cosinus", "accuracy_manhatten", "accuracy_euclidean"]
+        self.write_csv = write_csv
 
     @classmethod
     def from_input_examples(cls, examples: List[InputExample], **kwargs):
@@ -62,26 +79,28 @@ class TripletEvaluator(SentenceEvaluator):
         else:
             out_txt = ":"
 
-        logger.info("TripletEvaluator: Evaluating the model on "+self.name+" dataset"+out_txt)
+        logger.info("TripletEvaluator: Evaluating the model on " + self.name + " dataset" + out_txt)
 
         num_triplets = 0
         num_correct_cos_triplets, num_correct_manhatten_triplets, num_correct_euclidean_triplets = 0, 0, 0
 
-        embeddings_anchors = model.encode(self.anchors, batch_size=self.batch_size,
-                                          show_progress_bar=self.show_progress_bar, convert_to_numpy=True)
-        embeddings_positives = model.encode(self.positives, batch_size=self.batch_size,
-                                          show_progress_bar=self.show_progress_bar, convert_to_numpy=True)
-        embeddings_negatives = model.encode(self.negatives, batch_size=self.batch_size,
-                                          show_progress_bar=self.show_progress_bar, convert_to_numpy=True)
+        embeddings_anchors = model.encode(
+            self.anchors, batch_size=self.batch_size, show_progress_bar=self.show_progress_bar, convert_to_numpy=True
+        )
+        embeddings_positives = model.encode(
+            self.positives, batch_size=self.batch_size, show_progress_bar=self.show_progress_bar, convert_to_numpy=True
+        )
+        embeddings_negatives = model.encode(
+            self.negatives, batch_size=self.batch_size, show_progress_bar=self.show_progress_bar, convert_to_numpy=True
+        )
 
-
-        #Cosine distance
+        # Cosine distance
         pos_cos_distance = paired_cosine_distances(embeddings_anchors, embeddings_positives)
         neg_cos_distances = paired_cosine_distances(embeddings_anchors, embeddings_negatives)
 
-        # Manhatten
-        pos_manhatten_distance = paired_manhattan_distances(embeddings_anchors, embeddings_positives)
-        neg_manhatten_distances = paired_manhattan_distances(embeddings_anchors, embeddings_negatives)
+        # Manhattan
+        pos_manhattan_distance = paired_manhattan_distances(embeddings_anchors, embeddings_positives)
+        neg_manhattan_distances = paired_manhattan_distances(embeddings_anchors, embeddings_negatives)
 
         # Euclidean
         pos_euclidean_distance = paired_euclidean_distances(embeddings_anchors, embeddings_positives)
@@ -93,38 +112,38 @@ class TripletEvaluator(SentenceEvaluator):
             if pos_cos_distance[idx] < neg_cos_distances[idx]:
                 num_correct_cos_triplets += 1
 
-            if pos_manhatten_distance[idx] < neg_manhatten_distances[idx]:
+            if pos_manhattan_distance[idx] < neg_manhattan_distances[idx]:
                 num_correct_manhatten_triplets += 1
 
             if pos_euclidean_distance[idx] < neg_euclidean_distances[idx]:
                 num_correct_euclidean_triplets += 1
 
         accuracy_cos = num_correct_cos_triplets / num_triplets
-        accuracy_manhatten = num_correct_manhatten_triplets / num_triplets
+        accuracy_manhattan = num_correct_manhatten_triplets / num_triplets
         accuracy_euclidean = num_correct_euclidean_triplets / num_triplets
 
-        logger.info("Accuracy Cosine Distance:   \t{:.2f}".format(accuracy_cos*100))
-        logger.info("Accuracy Manhatten Distance:\t{:.2f}".format(accuracy_manhatten*100))
-        logger.info("Accuracy Euclidean Distance:\t{:.2f}\n".format(accuracy_euclidean*100))
+        logger.info("Accuracy Cosine Distance:   \t{:.2f}".format(accuracy_cos * 100))
+        logger.info("Accuracy Manhattan Distance:\t{:.2f}".format(accuracy_manhattan * 100))
+        logger.info("Accuracy Euclidean Distance:\t{:.2f}\n".format(accuracy_euclidean * 100))
 
-        if output_path is not None:
+        if output_path is not None and self.write_csv:
             csv_path = os.path.join(output_path, self.csv_file)
             if not os.path.isfile(csv_path):
-                with open(csv_path, mode="w", encoding="utf-8") as f:
+                with open(csv_path, newline="", mode="w", encoding="utf-8") as f:
                     writer = csv.writer(f)
                     writer.writerow(self.csv_headers)
-                    writer.writerow([epoch, steps, accuracy_cos, accuracy_manhatten, accuracy_euclidean])
+                    writer.writerow([epoch, steps, accuracy_cos, accuracy_manhattan, accuracy_euclidean])
 
             else:
-                with open(csv_path, mode="a", encoding="utf-8") as f:
+                with open(csv_path, newline="", mode="a", encoding="utf-8") as f:
                     writer = csv.writer(f)
-                    writer.writerow([epoch, steps, accuracy_cos, accuracy_manhatten, accuracy_euclidean])
+                    writer.writerow([epoch, steps, accuracy_cos, accuracy_manhattan, accuracy_euclidean])
 
         if self.main_distance_function == SimilarityFunction.COSINE:
             return accuracy_cos
         if self.main_distance_function == SimilarityFunction.MANHATTAN:
-            return accuracy_manhatten
+            return accuracy_manhattan
         if self.main_distance_function == SimilarityFunction.EUCLIDEAN:
             return accuracy_euclidean
 
-        return max(accuracy_cos, accuracy_manhatten, accuracy_euclidean)
+        return max(accuracy_cos, accuracy_manhattan, accuracy_euclidean)
